---
title: StatusInfo
react: StatusInfo
figma: 'https://www.figma.com/file/AVUutwoy459UAe35hEnEwl/?node-id=931%3A160172'
sections:
  - main
  - store
redirectFrom:
  - /components/empty-state
timestamp: '2021-05-03'
---

import { Card, Icon, LabeledList, LabeledListItem } from 'gds';

StatusInfo communicates information to the user with additional visual weight.

It is often used as an "Empty State" placeholder -- to avoid having large empty areas, but also to describe what might show up in this area once certain criteria are met, e.g. the user has added the first item to a previously empty list.

StatusInfo is also used to create [Success & Error cards](../examples/success-error-card).

## Usage

For good looks, even in its purest form, the StatusInfo always comes with a nice big icon/animation and a headline.

### Nested inside a card

Per default, the StatusInfo has to be shown inside a card.

<Preview demo="StatusInfoCard" />

GUIDELINES: do

- Try to add a call to action to an StatusInfo or display information on how to remove the Empty State.

RULES: design

- Usage of an icon/animation and headline is mandatory
- Usage of body text and call to action (primary and secondary) is optional
- If a StatusInfo is the first element of a page, it should replace the H1 to avoid redundancy
- Important components such as credit card box, function card, alert, etc. are to be positioned above the empty state
- Primary actions (e.g. a FunctionCard) are to be positioned above an empty state
- Secondary actions (e.g. "Create from preset") are to be positioned below an empty state

RULES: copy

- If the headline breaks on desktop, shorten the headline. Otherwise there are too many lines on mobile phones.

RULES: a11y

- H1 should be hidden

### On regular background

As an exception, the StatusInfo can be placed on a default background.

<Preview demo="StatusInfoPlain" />

## Rich content

Rich content and a multitude of buttons can be used as well.

<Preview demo="StatusInfoRich" />

## Icons

A grey icon (<Color name="gray-300" />) must be used when the product is empty or there is no content to display.

RULES: design

- Icons have to be descriptive
- Use the `file` icon for an StatusInfo with documents
- Use the `list` icon for an StatusInfo with lists
- Use the `comment` icon for an StatusInfo with messages
- Use the `search` icon for an StatusInfo with filter or search results
- You may use custom icons if applicable - in all other cases of StatusInfos use the `empty-state-generic` icon

<Preview>
  <Card nested={false}>
    <LabeledList labelColumnWidth={6}>
      <LabeledListItem label="With documents">
        <Icon icon={Icon.ICON.FILE} size={Icon.SIZE.SIZE_48} color={Icon.COLOR.GRAY_300} /> file
      </LabeledListItem>
      <LabeledListItem label="With lists">
        <Icon icon={Icon.ICON.LIST} size={Icon.SIZE.SIZE_48} color={Icon.COLOR.GRAY_300} /> list
      </LabeledListItem>
      <LabeledListItem label="With messages">
        <Icon icon={Icon.ICON.COMMENT} size={Icon.SIZE.SIZE_48} color={Icon.COLOR.GRAY_300} />{' '}
        comment
      </LabeledListItem>
      <LabeledListItem label="With filter or search results">
        <Icon icon={Icon.ICON.SEARCH} size={Icon.SIZE.SIZE_48} color={Icon.COLOR.GRAY_300} /> search
      </LabeledListItem>
      <LabeledListItem label="Default">
        <Icon
          icon={Icon.ICON.EMPTY_STATE_GENERIC}
          size={Icon.SIZE.SIZE_48}
          color={Icon.COLOR.GRAY_300}
        />{' '}
        emptystate
      </LabeledListItem>
    </LabeledList>
  </Card>
</Preview>
